==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1PodAntiAffinityFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1PodAntiAffinityFluent<A extends V1PodAntiAffinityFluent<A>> extends Fluent<A>{


    public A addToPreferredDuringSchedulingIgnoredDuringExecution(int index,V1WeightedPodAffinityTerm item);
    public A setToPreferredDuringSchedulingIgnoredDuringExecution(int index,V1WeightedPodAffinityTerm item);
    public A addToPreferredDuringSchedulingIgnoredDuringExecution(V1WeightedPodAffinityTerm... items);
    public A addAllToPreferredDuringSchedulingIgnoredDuringExecution(Collection<V1WeightedPodAffinityTerm> items);
    public A removeFromPreferredDuringSchedulingIgnoredDuringExecution(V1WeightedPodAffinityTerm... items);
    public A removeAllFromPreferredDuringSchedulingIgnoredDuringExecution(Collection<V1WeightedPodAffinityTerm> items);
    
/**
 * This method has been deprecated, please use method buildPreferredDuringSchedulingIgnoredDuringExecution instead.
 * @return The buildable object.
 */
@Deprecated public List<V1WeightedPodAffinityTerm> getPreferredDuringSchedulingIgnoredDuringExecution();
    public List<V1WeightedPodAffinityTerm> buildPreferredDuringSchedulingIgnoredDuringExecution();
    public V1WeightedPodAffinityTerm buildPreferredDuringSchedulingIgnoredDuringExecution(int index);
    public V1WeightedPodAffinityTerm buildFirstPreferredDuringSchedulingIgnoredDuringExecution();
    public V1WeightedPodAffinityTerm buildLastPreferredDuringSchedulingIgnoredDuringExecution();
    public V1WeightedPodAffinityTerm buildMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1WeightedPodAffinityTermBuilder> predicate);
    public A withPreferredDuringSchedulingIgnoredDuringExecution(List<V1WeightedPodAffinityTerm> preferredDuringSchedulingIgnoredDuringExecution);
    public A withPreferredDuringSchedulingIgnoredDuringExecution(V1WeightedPodAffinityTerm... preferredDuringSchedulingIgnoredDuringExecution);
    public Boolean hasPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecutionLike(V1WeightedPodAffinityTerm item);
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> setNewPreferredDuringSchedulingIgnoredDuringExecutionLike(int index,V1WeightedPodAffinityTerm item);
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editPreferredDuringSchedulingIgnoredDuringExecution(int index);
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editLastPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1WeightedPodAffinityTermBuilder> predicate);
    public A addToRequiredDuringSchedulingIgnoredDuringExecution(int index,V1PodAffinityTerm item);
    public A setToRequiredDuringSchedulingIgnoredDuringExecution(int index,V1PodAffinityTerm item);
    public A addToRequiredDuringSchedulingIgnoredDuringExecution(V1PodAffinityTerm... items);
    public A addAllToRequiredDuringSchedulingIgnoredDuringExecution(Collection<V1PodAffinityTerm> items);
    public A removeFromRequiredDuringSchedulingIgnoredDuringExecution(V1PodAffinityTerm... items);
    public A removeAllFromRequiredDuringSchedulingIgnoredDuringExecution(Collection<V1PodAffinityTerm> items);
    
/**
 * This method has been deprecated, please use method buildRequiredDuringSchedulingIgnoredDuringExecution instead.
 * @return The buildable object.
 */
@Deprecated public List<V1PodAffinityTerm> getRequiredDuringSchedulingIgnoredDuringExecution();
    public List<V1PodAffinityTerm> buildRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAffinityTerm buildRequiredDuringSchedulingIgnoredDuringExecution(int index);
    public V1PodAffinityTerm buildFirstRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAffinityTerm buildLastRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAffinityTerm buildMatchingRequiredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PodAffinityTermBuilder> predicate);
    public A withRequiredDuringSchedulingIgnoredDuringExecution(List<V1PodAffinityTerm> requiredDuringSchedulingIgnoredDuringExecution);
    public A withRequiredDuringSchedulingIgnoredDuringExecution(V1PodAffinityTerm... requiredDuringSchedulingIgnoredDuringExecution);
    public Boolean hasRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> addNewRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> addNewRequiredDuringSchedulingIgnoredDuringExecutionLike(V1PodAffinityTerm item);
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> setNewRequiredDuringSchedulingIgnoredDuringExecutionLike(int index,V1PodAffinityTerm item);
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editRequiredDuringSchedulingIgnoredDuringExecution(int index);
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editLastRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingRequiredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PodAffinityTermBuilder> predicate);

    public interface PreferredDuringSchedulingIgnoredDuringExecutionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1WeightedPodAffinityTermFluent<V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<N>>{

        
    public N and();    public N endPreferredDuringSchedulingIgnoredDuringExecution();
}
    public interface RequiredDuringSchedulingIgnoredDuringExecutionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1PodAffinityTermFluent<V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<N>>{

        
    public N and();    public N endRequiredDuringSchedulingIgnoredDuringExecution();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1PodAntiAffinityFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1PodAntiAffinityFluent<A extends V1PodAntiAffinityFluent<A>> extends Fluent<A>{


    public A addToPreferredDuringSchedulingIgnoredDuringExecution(int index,V1WeightedPodAffinityTerm item);
    public A setToPreferredDuringSchedulingIgnoredDuringExecution(int index,V1WeightedPodAffinityTerm item);
    public A addToPreferredDuringSchedulingIgnoredDuringExecution(V1WeightedPodAffinityTerm... items);
    public A addAllToPreferredDuringSchedulingIgnoredDuringExecution(Collection<V1WeightedPodAffinityTerm> items);
    public A removeFromPreferredDuringSchedulingIgnoredDuringExecution(V1WeightedPodAffinityTerm... items);
    public A removeAllFromPreferredDuringSchedulingIgnoredDuringExecution(Collection<V1WeightedPodAffinityTerm> items);
    
/**
 * This method has been deprecated, please use method buildPreferredDuringSchedulingIgnoredDuringExecution instead.
 * @return The buildable object.
 */
@Deprecated public List<V1WeightedPodAffinityTerm> getPreferredDuringSchedulingIgnoredDuringExecution();
    public List<V1WeightedPodAffinityTerm> buildPreferredDuringSchedulingIgnoredDuringExecution();
    public V1WeightedPodAffinityTerm buildPreferredDuringSchedulingIgnoredDuringExecution(int index);
    public V1WeightedPodAffinityTerm buildFirstPreferredDuringSchedulingIgnoredDuringExecution();
    public V1WeightedPodAffinityTerm buildLastPreferredDuringSchedulingIgnoredDuringExecution();
    public V1WeightedPodAffinityTerm buildMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1WeightedPodAffinityTermBuilder> predicate);
    public Boolean hasMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1WeightedPodAffinityTermBuilder> predicate);
    public A withPreferredDuringSchedulingIgnoredDuringExecution(List<V1WeightedPodAffinityTerm> preferredDuringSchedulingIgnoredDuringExecution);
    public A withPreferredDuringSchedulingIgnoredDuringExecution(V1WeightedPodAffinityTerm... preferredDuringSchedulingIgnoredDuringExecution);
    public Boolean hasPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecutionLike(V1WeightedPodAffinityTerm item);
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> setNewPreferredDuringSchedulingIgnoredDuringExecutionLike(int index,V1WeightedPodAffinityTerm item);
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editPreferredDuringSchedulingIgnoredDuringExecution(int index);
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editLastPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1WeightedPodAffinityTermBuilder> predicate);
    public A addToRequiredDuringSchedulingIgnoredDuringExecution(int index,V1PodAffinityTerm item);
    public A setToRequiredDuringSchedulingIgnoredDuringExecution(int index,V1PodAffinityTerm item);
    public A addToRequiredDuringSchedulingIgnoredDuringExecution(V1PodAffinityTerm... items);
    public A addAllToRequiredDuringSchedulingIgnoredDuringExecution(Collection<V1PodAffinityTerm> items);
    public A removeFromRequiredDuringSchedulingIgnoredDuringExecution(V1PodAffinityTerm... items);
    public A removeAllFromRequiredDuringSchedulingIgnoredDuringExecution(Collection<V1PodAffinityTerm> items);
    
/**
 * This method has been deprecated, please use method buildRequiredDuringSchedulingIgnoredDuringExecution instead.
 * @return The buildable object.
 */
@Deprecated public List<V1PodAffinityTerm> getRequiredDuringSchedulingIgnoredDuringExecution();
    public List<V1PodAffinityTerm> buildRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAffinityTerm buildRequiredDuringSchedulingIgnoredDuringExecution(int index);
    public V1PodAffinityTerm buildFirstRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAffinityTerm buildLastRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAffinityTerm buildMatchingRequiredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PodAffinityTermBuilder> predicate);
    public Boolean hasMatchingRequiredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PodAffinityTermBuilder> predicate);
    public A withRequiredDuringSchedulingIgnoredDuringExecution(List<V1PodAffinityTerm> requiredDuringSchedulingIgnoredDuringExecution);
    public A withRequiredDuringSchedulingIgnoredDuringExecution(V1PodAffinityTerm... requiredDuringSchedulingIgnoredDuringExecution);
    public Boolean hasRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> addNewRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> addNewRequiredDuringSchedulingIgnoredDuringExecutionLike(V1PodAffinityTerm item);
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> setNewRequiredDuringSchedulingIgnoredDuringExecutionLike(int index,V1PodAffinityTerm item);
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editRequiredDuringSchedulingIgnoredDuringExecution(int index);
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editLastRequiredDuringSchedulingIgnoredDuringExecution();
    public V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingRequiredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PodAffinityTermBuilder> predicate);

    public interface PreferredDuringSchedulingIgnoredDuringExecutionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1WeightedPodAffinityTermFluent<V1PodAntiAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<N>>{

        
    public N and();    public N endPreferredDuringSchedulingIgnoredDuringExecution();
}
    public interface RequiredDuringSchedulingIgnoredDuringExecutionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1PodAffinityTermFluent<V1PodAntiAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<N>>{

        
    public N and();    public N endRequiredDuringSchedulingIgnoredDuringExecution();
}


}
